Arguments
object
Object describing the fitted mixture of regressions, as returned
by mixreg.
cov.mat
The estimated covariance matrix of the parameter estimates of the
fit, as returned by covmix.
x
The vector of predictors for each of the regression models in the
mixture. Only one-dimensional predictors are permitted here.
y
The vector of responses for the regression models.
alpha
One minus the confidence level for the confidence and prediction
bands; e.g. alpha = 0.05 for 95% confidence.
xlen
The number of points to be plotted in the band envelopes. The
x-values of the points will be equi-spaced from min(x) to max(x).
plotit
Logical argument indicating whether to plot the fitted model
and confidence bands.
type
Character argument specifying the type of band. Must have one
of the values "both", "upper", or "lower". Defaults to "both".