covmix(object, x, y)In the foregoing beta refers to the linear coefficients, sigsq to the variance, and lambda to the mixing probability.
Louis, T. A. Finding the observed information matrix when using the EM algorithm, J. R. Statist. Soc. B, vol. 44, pp. 226 -- 233, 1982.
#See \link{mixreg} for examples.Run the code above in your browser using DataLab