Arguments
object
A list with components containing the residuals, the relevant
probabilities, the predictors, and the observations, as returned
by resid.mix; probably the residuals should be standardized for
use by qq.mix, i.e. resid.mix should be called with std=TRUE.
xlim
The limits (endpoints) of the x axis of the plot; chosen in
the "usual" way by the plotting software if xlim is NULL.
ylim
The limits (endpoints) of the y axis of the plot; chosen in
the "usual" way by the plotting software if ylim is NULL.
shape
The shape of the plotting symbol; possible values are "disc",
"square", and "diamond". Partial matching is used so only
the first few letters need be given.
ngon
The "disc" shape is actually a regular polygon; ngon specifies
how many sides it should have; ignored if shape is not equal
to "disc".
size
A scale factor to change the absolute sizes of the plotting
symbols; values larger than 1 make the symbols larger than
the default; values less than 1 make them smaller.
...
Additional arguments to be passed to the polygon function which
actually draws the plotting symbols.